@@ -2,7 +2,7 @@ package Text::Transliterator;
 use strict;
 use warnings;
 
-our $VERSION = '1.03';
+our $VERSION = '1.05';
 
 sub new {
   my $class = shift;
@@ -26,10 +26,12 @@ sub new {
   not @_
     or die 'Text::Transliterator->new(): too many args';
 
-  # build the coderef
-  my $src = "sub {tr[$from][$to]$modifiers for \@_ }";
+  # build the coderef.
+  # Returns the list of tr/../../ results.
+  # In scalar context, returns the last item (for compatibility with the previous API)
+  my $src = "sub {my \@l = map {tr[$from][$to]$modifiers} \@_; return wantarray ? \@l : \$l[-1]}";
   local $@;
-  my $coderef = eval $src or die $@;
+  my $coderef = eval $src or die "Text::Transliterator: error in compiling the tr function: $@";
 
   return $coderef;
 }
@@ -85,69 +87,34 @@ directly to the C<tr/.../.../> operator
 i.e. a string of characters to be replaced,
 and a string of replacement characters.  The third argument
 C<$modifiers> is optional and may contain a string with any
-combination of the C<cds> modifiers to the C<tr/.../.../> operator.
+combination of the C<cdsr> modifiers to the C<tr/.../.../> operator.
 
 In the second syntax, the argument is a hashref, in which
 keys are the characters to be replaced, and values are the
 replacement characters. Optional C<$modifiers> are as above.
 
-The return value from that C<new> method is actually
-a reference to a function, not an object. That function is called as
+Unlike usual object-oriented modules, here the return value from
+the C<new> method is a reference to a function, not an object.
+That function should be called as
 
   $tr->(@strings);
 
-and modifies every member of C<@strings> I<in place>,
-like the C<tr/.../.../> operator.
-The return value is the number of transliterated characters
-in the last member of C<@strings>.
+and modifies every member of C<@strings>.
+By default strings are modified I<in place>,like with the C<tr/.../.../> operator,
+unless the C<r> modifier is present.
+
+The function returns the list of results of the C<tr/.../.../> operation on each of the input strings.
+By default this will be the number of transliterated characters for each string.
+If the C<r> modifier is present, the return value is the list of transliterated strings.
+In scalar context, the last member of the list is returned (for compatibility with the previous API).
 
 =head1 AUTHOR
 
 Laurent Dami, C<< <dami@cpan.org> >>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to
-C<bug-text-transliterator at rt.cpan.org>, or through the web
-interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Text-Transliterator>.
-I will be notified, and then you'll automatically be notified of
-progress on your bug as I make changes.
-
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Text::Transliterator
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Text-Transliterator>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Text-Transliterator>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Text-Transliterator>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Text-Transliterator/>
-
-=back
-
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010, 2017 Laurent Dami.
+Copyright 2010-2025 Laurent Dami.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
